| linComb | R Documentation |
The linComb function calculates the combination
scores of two diagnostic tests selected among several linear combination
methods and standardization options.
linComb(
markers = NULL,
status = NULL,
event = NULL,
method = c("scoring", "SL", "logistic", "minmax", "PT", "PCL", "minimax", "TS"),
resample = c("none", "cv", "repeatedcv", "boot"),
nfolds = 5,
nrepeats = 3,
niters = 10,
standardize = c("none", "min_max_scale", "zScore", "tScore", "scale_mean_to_one",
"scale_sd_to_one"),
ndigits = 0,
show.plot = TRUE,
direction = c("<", ">"),
conf.level = 0.95,
cutoff.method = c("CB", "MCT", "MinValueSp", "MinValueSe", "ValueSp", "ValueSe",
"MinValueSpSe", "MaxSp", "MaxSe", "MaxSpSe", "MaxProdSpSe", "ROC01", "SpEqualSe",
"Youden", "MaxEfficiency", "Minimax", "MaxDOR", "MaxKappa", "MinValueNPV",
"MinValuePPV", "ValueNPV", "ValuePPV", "MinValueNPVPPV", "PROC01", "NPVEqualPPV",
"MaxNPVPPV", "MaxSumNPVPPV", "MaxProdNPVPPV", "ValueDLR.Negative",
"ValueDLR.Positive", "MinPvalue", "ObservedPrev", "MeanPrev", "PrevalenceMatching"),
show.result = FALSE,
...
)
markers |
a |
status |
a |
event |
a |
method |
a The available methods are:
|
resample |
a
|
nfolds |
a |
nrepeats |
a |
niters |
a |
standardize |
a
|
ndigits |
a |
show.plot |
a |
direction |
a |
conf.level |
a |
cutoff.method |
a |
show.result |
a |
... |
further arguments. Currently has no effect on the results. |
A list of numeric linear combination scores calculated
according to the given method and standardization option.
Serra Ilayda Yerlitas Tastan, Serra Bersan Gengec, Necla Kochan, Gozde Erturk Zararsiz, Selcuk Korkmaz, Gokmen Zararsiz
# call data
data(laparotomy)
# define the function parameters
markers <- laparotomy[, -1]
status <- factor(laparotomy$group, levels = c("not_needed", "needed"))
event <- "needed"
score1 <- linComb(
markers = markers, status = status, event = event,
method = "logistic", resample = "none", show.plot = TRUE,
standardize = "none", direction = "<", cutoff.method = "Youden"
)
# call data
data(exampleData2)
# define the function parameters
markers <- exampleData2[, -c(1:3, 6:7)]
status <- factor(exampleData2$Group, levels = c("normals", "carriers"))
event <- "carriers"
score2 <- linComb(
markers = markers, status = status, event = event,
method = "PT", resample = "none", standardize = "none", direction = "<",
cutoff.method = "Youden", show.result = TRUE
)
score3 <- linComb(
markers = markers, status = status, event = event,
method = "minmax", resample = "none", direction = "<",
cutoff.method = "Youden"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.