| mlComb | R Documentation |
The mlComb function calculates the combination
scores of two diagnostic tests selected among several Machine Learning
Algorithms
mlComb(
markers = NULL,
status = NULL,
event = NULL,
method = NULL,
resample = NULL,
niters = 10,
nfolds = 5,
nrepeats = 3,
preProcess = NULL,
show.plot = TRUE,
B = 25,
direction = c("<", ">"),
conf.level = 0.95,
p = 0.75,
cutoff.method = c("CB", "MCT", "MinValueSp", "MinValueSe", "ValueSp", "ValueSe",
"MinValueSpSe", "MaxSp", "MaxSe", "MaxSpSe", "MaxProdSpSe", "ROC01", "SpEqualSe",
"Youden", "MaxEfficiency", "Minimax", "MaxDOR", "MaxKappa", "MinValueNPV",
"MinValuePPV", "ValueNPV", "ValuePPV", "MinValueNPVPPV", "PROC01", "NPVEqualPPV",
"MaxNPVPPV", "MaxSumNPVPPV", "MaxProdNPVPPV", "ValueDLR.Negative",
"ValueDLR.Positive", "MinPvalue", "ObservedPrev", "MeanPrev", "PrevalenceMatching"),
show.result = FALSE,
...
)
markers |
a |
status |
a |
event |
a |
method |
a IMPORTANT: See https://topepo.github.io/caret/available-models.html for further information about the methods used in this function. |
resample |
A character string specifying the resampling method used while
training the model. Available methods are |
niters |
A positive integer indicating the number of bootstrap
resampling iterations. Used for |
nfolds |
A positive integer. For |
nrepeats |
A positive integer indicating the number of repeats for
|
preProcess |
a |
show.plot |
a |
B |
a |
direction |
a |
conf.level |
a |
p |
A numeric value between 0 and 1 specifying the training proportion
used for |
cutoff.method |
a |
show.result |
a |
... |
optional arguments passed to selected classifiers. |
A list of AUC values, diagnostic statistics,
coordinates of the ROC curve for the combination score obtained using
Machine Learning Algorithms as well as the given biomarkers individually, a
comparison table for the AUC values of individual biomarkers and combination
score obtained and the fitted model.
Serra Ilayda Yerlitas Tastan, Serra Bersan Gengec, Necla Kochan, Gozde Erturk Zararsiz, Selcuk Korkmaz, Gokmen Zararsiz
availableMethods, caret::train,
caret::trainControl
# call data
data(laparotomy)
# define the function parameters
markers <- laparotomy[, -1]
status <- factor(laparotomy$group, levels = c("not_needed", "needed"))
event <- "needed"
model <- mlComb(
markers = markers, status = status, event = event,
method = "knn", resample = "cv", nfolds = 5,
preProcess = c("center", "scale"), direction = "<", cutoff.method = "Youden"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.