| validateLinComb | R Documentation |
linCombInternal helper used by linComb to validate linear-combination-specific
arguments. It checks the selected combination method, resampling method,
standardization method, and method-specific standardization requirements.
It also adjusts nrepeats when resample = "cv" and forces the
required standardization for selected methods.
validateLinComb(
method = c("scoring", "SL", "logistic", "minmax", "PT", "PCL", "minimax", "TS"),
resample = c("none", "cv", "repeatedcv", "boot"),
nfolds = 5,
nrepeats = 3,
niters = 10,
standardize = c("none", "min_max_scale", "zScore", "tScore", "scale_mean_to_one",
"scale_sd_to_one"),
ndigits = 0
)
method |
A character string specifying the linear combination method.
Available methods are |
resample |
A character string specifying the resampling method. Available
options are |
nfolds |
A positive integer indicating the number of folds for cross-validation-based resampling methods. Default is 5. |
nrepeats |
A positive integer indicating the number of repeats for
|
niters |
A positive integer indicating the number of bootstrap
resampling iterations when |
standardize |
A character string specifying the standardization method.
Available options are |
ndigits |
A non-negative integer indicating the number of decimal places
used for rounding coefficients in the |
The "minmax" and "PCL" methods require
standardize = "min_max_scale". If another standardization method is
supplied, it is replaced with "min_max_scale" and a warning is issued.
The "PT" method requires standardize = "zScore". If another
standardization method is supplied, it is replaced with "zScore" and a
warning is issued.
A list containing the validated and prepared values:
method, resample,
nfolds, nrepeats, niters,
standardize, and ndigits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.