| validateMathComb | R Documentation |
mathCombInternal helper used by mathComb to validate mathematical-combination
specific arguments. It checks the selected mathematical operator, distance
metric, standardization method, transformation method, and marker-value
requirements for selected transformations.
validateMathComb(
markers,
method = c("add", "multiply", "divide", "subtract", "distance", "baseinexp",
"expinbase"),
distance = c("euclidean", "manhattan", "chebyshev", "kulczynski_d", "lorentzian",
"avg", "taneja", "kumar-johnson"),
standardize = c("none", "min_max_scale", "zScore", "tScore", "scale_mean_to_one",
"scale_sd_to_one"),
transform = c("none", "log", "exp", "sin", "cos")
)
markers |
A numeric data frame or matrix containing the marker values.
Marker values must be finite. If |
method |
A character string specifying the mathematical combination
method. Available methods are |
distance |
A character string specifying the distance metric used when
|
standardize |
A character string specifying the standardization method.
Available options are |
transform |
A character string specifying the transformation applied to
marker values. Available options are |
A list containing the validated and prepared values:
standardize and transform.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.