| validateNonlinComb | R Documentation |
nonlinCombInternal helper used by nonlinComb to validate
nonlinear-combination-specific arguments. It checks the selected nonlinear
combination method, polynomial degrees, spline/GAM degrees of freedom,
resampling method and related resampling parameters, standardization method,
interaction option, and elastic net mixing parameter.
validateNonlinComb(
method = c("polyreg", "ridgereg", "lassoreg", "elasticreg", "splines", "sgam", "nsgam"),
degree1 = 3,
degree2 = 3,
df1 = 4,
df2 = 4,
resample = c("none", "cv", "repeatedcv", "boot"),
nfolds = 5,
nrepeats = 3,
niters = 10,
standardize = c("none", "min_max_scale", "zScore", "tScore", "scale_mean_to_one",
"scale_sd_to_one"),
include.interact = FALSE,
alpha = 0.5
)
method |
A character string specifying the nonlinear combination method.
Available methods are |
degree1 |
A positive integer specifying the polynomial degree for the first marker in polynomial-based methods. Default is 3. |
degree2 |
A positive integer specifying the polynomial degree for the second marker in polynomial-based methods. Default is 3. |
df1 |
A positive integer specifying the degrees of freedom for the first marker in spline/GAM-based methods. Default is 4. |
df2 |
A positive integer specifying the degrees of freedom for the second marker in spline/GAM-based methods. Default is 4. |
resample |
A character string specifying the resampling method. Available
options are |
nfolds |
A positive integer indicating the number of folds for cross-validation-based resampling methods. Default is 5. |
nrepeats |
A positive integer indicating the number of repeats for
|
niters |
A positive integer indicating the number of bootstrap
resampling iterations when |
standardize |
A character string specifying the standardization method.
Available options are |
include.interact |
A logical value indicating whether the interaction
term between the two markers should be included in polynomial-based methods.
Default is |
alpha |
A numeric value between 0 and 1 specifying the elastic net mixing
parameter when |
A list containing the validated and prepared values:
method, degree1, degree2, df1, df2,
resample, nfolds, nrepeats, niters,
standardize, include.interact, and alpha.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.